@@ -6,11 +6,11 @@
         $squirrelmail_plugin_hooks["read_body_bottom"]["get_uuencode"] = "get_uuencode_read_body_bottom";
     }
     function get_uuencode_message_body(&$data) {
-        include_once('../plugins/get_uuencode/get_uuencode.php');
+        include_once(SM_PATH . 'plugins/get_uuencode/get_uuencode.php');
         get_uuencode_body($data);
     }
     function get_uuencode_read_body_bottom () {
-        include_once('../plugins/get_uuencode/get_uuencode.php');
+        include_once(SM_PATH . 'plugins/get_uuencode/get_uuencode.php');
         get_uuencode_link();
     }
 ?>
